@@ -30,7 +30,7 @@ from .lss import LinearStateSpace
 from .matrix_eqn import solve_discrete_lyapunov, solve_discrete_riccati
 from .quadsums import var_quadratic_sum, m_quadratic_sum
 #->Propose Delete From Top Level
-from .markov import MarkovChain, random_markov_chain, random_stochastic_matrix, gth_solve, tauchen 	 	#Promote to keep current examples working
+from .markov import MarkovChain, random_markov_chain, random_stochastic_matrix, gth_solve, tauchen, rouwenhorst 	 	#Promote to keep current examples working
 from .markov import mc_compute_stationary, mc_sample_path 												#Imports that Should be Deprecated with markov package
 #<-
 from .rank_nullspace import rank_est, nullspace
