@@ -276,20 +276,20 @@ class Player(object):
 
         Parameters
         ----------
-        opponents_actions : array_like(int or array_like(float)) or
-                            array_like(int, ndim=1) or scalar(int)
-            A profile of N-1 opponents' actions. If N=2, then it must be
-            a 1-dimensional array of floats (in which case it is treated
-            as the opponent's mixed action) or a scalar of integer (in
-            which case it is treated as the opponent's pure action). If
-            N>2, then it must be an array of N-1 objects, where each
-            object must be an integer (pure action) or an array of
-            floats (mixed action).
+        opponents_actions : scalar(int) or array_like
+            A profile of N-1 opponents' actions, represented by either
+            scalar(int), array_like(float), array_like(int), or
+            array_like(array_like(float)). If N=2, then it must be a
+            scalar of integer (in which case it is treated as the
+            opponent's pure action) or a 1-dimensional array of floats
+            (in which case it is treated as the opponent's mixed
+            action). If N>2, then it must be an array of N-1 objects,
+            where each object must be an integer (pure action) or an
+            array of floats (mixed action).
 
-        tie_breaking : {'smallest', 'random', False},
-                       optional(default='smallest')
-            Control how, or whether, to break a tie (see Returns for
-            details).
+        tie_breaking : str, optional(default='smallest')
+            str in {'smallest', 'random', False}. Control how, or 
+            whether, to break a tie (see Returns for details).
 
         payoff_perturbation : array_like(float), optional(default=None)
             Array of length equal to the number of actions of the player
@@ -300,8 +300,7 @@ class Player(object):
             Tolerance level used in determining best responses. If None,
             default to the value of the `tol` attribute.
 
-        random_state : scalar(int) or np.random.RandomState,
-                       optional(default=None)
+        random_state : int or np.random.RandomState, optional
             Random seed (integer) or np.random.RandomState instance to
             set the initial state of the random number generator for
             reproducibility. If None, a randomly initialized RandomState
@@ -350,8 +349,7 @@ class Player(object):
         actions : array_like(int), optional(default=None)
             An array of integers representing pure actions.
 
-        random_state : scalar(int) or np.random.RandomState,
-                       optional(default=None)
+        random_state : int or np.random.RandomState, optional
             Random seed (integer) or np.random.RandomState instance to
             set the initial state of the random number generator for
             reproducibility. If None, a randomly initialized RandomState
@@ -389,8 +387,7 @@ class NormalFormGame(object):
 
     Parameters
     ----------
-    data : array_like(Player) or array_like(int, ndim=1) or
-           array_like(float, ndim=2 or N+1)
+    data : array_like of Player, int (ndim=1), or float (ndim=2 or N+1)
         Data to initialize a NormalFormGame. `data` may be an array of
         Players, in which case the shapes of the Players' payoff arrays
         must be consistent. If `data` is an array of N integers, then
@@ -703,8 +700,8 @@ def best_response_2p(payoff_matrix, opponent_mixed_action, tol=1e-8):
     tol : scalar(float), optional(default=None)
         Tolerance level used in determining best responses.
 
-    Return
-    ------
+    Returns
+    -------
     scalar(int)
         Best response action.
 
